OC.L10N.register(
    "core",
    {
    "Please select a file." : "Vänligen välj en fil.",
    "File is too big" : "Filen är för stor",
    "Invalid file provided" : "En ogiltig fil tillhandahölls",
    "No image or file provided" : "Ingen bild eller fil har tillhandahållits",
    "Unknown filetype" : "Okänd filtyp",
    "Invalid image" : "Ogiltig bild",
    "An error occurred. Please contact your admin." : "Ett fel har inträffat. Kontakta din administratör.",
    "No temporary profile picture available, try again" : "Ingen temporär profilbild finns tillgänglig, försök igen",
    "No crop data provided" : "Ingen beskärdata har angivits",
    "No valid crop data provided" : "Ingen giltig beskärningsdata tillhandahölls",
    "Crop is not square" : "Beskärning är inte kvadratisk",
    "Couldn't reset password because the token is invalid" : "Kunde inte återställa lösenordet på grund av felaktig token",
    "Couldn't reset password because the token is expired" : "Lösenord kunde inte återställas eftersom \"token\" har utgått",
    "%s password reset" : "%s återställ lösenord",
    "Couldn't send reset email. Please contact your administrator." : "Kunde inte skicka återställningsmail. Vänligen kontakta din administratör.",
    "Couldn't send mail to following users: %s " : "Gick inte att skicka e-post till följande användare: %s",
    "Preparing update" : "Förbereder uppdatering",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Reperationsvarning:",
    "Repair error: " : "Reperationsfel:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Vänligen använd den kommandotolksbaserade uppdateringen då automatisk uppdatering är inaktiverat i config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrollerar tabell %s",
    "Turned on maintenance mode" : "Aktiverade underhållsläge",
    "Turned off maintenance mode" : "Deaktiverade underhållsläge",
    "Maintenance mode is kept active" : "Underhållsläget förblir aktivt",
    "Updating database schema" : "Uppdaterar databasschema",
    "Updated database" : "Uppdaterade databasen",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Kontrollerar om databasschema kan uppdateras (detta kan ta lång tid beroende på databasens storlek)",
    "Checked database schema update" : "Kontrollerade uppdatering av databasschemat",
    "Checking updates of apps" : "Kontrollerar uppdatering utav appar",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontrollerar om databasschema för %s kan uppdateras (detta kan ta lång tid beroende på databasens storlek)",
    "Checked database schema update for apps" : "Kontrollerade uppdatering av databasschemat för applikationer",
    "Updated \"%s\" to %s" : "Uppdaterade \"%s\" till %s",
    "Set log level to debug" : "Sätter loggingsnivå till \"debug\"",
    "Reset log level" : "Återställer loggningsnivå",
    "Starting code integrity check" : "Startar integritetskontroll av kod",
    "Finished code integrity check" : "Slutförde integritetskontroll av kod",
    "%s (3rdparty)" : "%s (3rdparty)",
    "%s (incompatible)" : "%s (incompatible)",
    "Following apps have been disabled: %s" : "Följande appar har inaktiverats: %s",
    "Already up to date" : "Redan uppdaterad",
    "Sunday" : "Söndag",
    "Monday" : "Måndag",
    "Tuesday" : "Tisdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lördag",
    "Sun." : "Sön.",
    "Mon." : "Mån.",
    "Tue." : "Tis.",
    "Wed." : "Ons.",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lör.",
    "Su" : "Sön",
    "Mo" : "Mån",
    "Tu" : "Tis",
    "We" : "Ons",
    "Th" : "Tors",
    "Fr" : "Fre",
    "Sa" : "Lör",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Mars",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Augusti",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\"> Ett problem uppstod under integritetskontrollen av koden. Mer information ... </a>",
    "Settings" : "Inställningar",
    "Problem loading page, reloading in 5 seconds" : "Problem med att ladda sidan, försöker igen om 5 sekunder",
    "Saving..." : "Sparar...",
    "Dismiss" : "Avfärda",
    "seconds ago" : "sekunder sedan",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Länken för att återställa ditt lösenord har skickats till din e-mail. Om du inte mottar något inom kort, kontrollera spam/skräpkorgen.<br>Om det inte finns något där, vänligen kontakta din lokala administratör.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Dina filer är krypterade. Om du inte angett någon återställningsnyckel, kommer det att vara omöjligt att få tillbaka dina data efter att lösenordet är återställt..<br />Om du är osäker på vad du ska göra, vänligen kontakta din administratör innan du fortsätter.<br />Är du verkligen helt säker på att du vill fortsätta?",
    "I know what I'm doing" : "Jag är säker på vad jag gör",
    "Password can not be changed. Please contact your administrator." : "Lösenordet kan inte ändras. Vänligen kontakta din administratör.",
    "No" : "Nej",
    "Yes" : "Ja",
    "Choose" : "Välj",
    "Error loading file picker template: {error}" : "Fel uppstod för filväljarmall: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Fel uppstod under inläsningen av meddelandemallen: {error}",
    "read-only" : "skrivskyddad",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonflikter"],
    "One file conflict" : "En filkonflikt",
    "New Files" : "Nya filer",
    "Already existing files" : "Filer som redan existerar",
    "Which files do you want to keep?" : "Vilken fil vill du behålla?",
    "If you select both versions, the copied file will have a number added to its name." : "Om du väljer båda versionerna kommer de kopierade filerna ha nummer tillagda i filnamnet.",
    "Cancel" : "Avbryt",
    "Continue" : "Fortsätt",
    "(all selected)" : "(Alla valda)",
    "({count} selected)" : "({count} valda)",
    "Error loading file exists template" : "Fel uppstod filmall existerar",
    "Very weak password" : "Väldigt svagt lösenord",
    "Weak password" : "Svagt lösenord",
    "So-so password" : "Okej lösenord",
    "Good password" : "Bra lösenord",
    "Strong password" : "Starkt lösenord",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Din webbserver är inte konfigurerad korrekt för att tillåta filsynkronisering eftersom WebDAV gränssnittet verkar otillgängligt.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Din webbserver är inte konfigurerad riktigt för att lösa \"{url}\". Vidare information kan hittas i vår <a target=\"_blank\" rel\"noreferrer\" href=\"{docLink}\">dokumentation</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Servern har ingen fungerande internetuppkoppling. Detta betyder att vissa funktioner så som extern lagring, notifikationer om uppdateringar eller installationer utav tredjeparts applikationer inte kommer fungera. Åtkomst av filer utifrån och att skicka notifieringar via epost kanske inte fungerar heller. Vi föreslår att man aktiverar internetanslutningen för denna server om man vill använda samtliga funktioner.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Ingen minnes cache har blivit konfigurerad. För att förbättra din prestanda var god konfigurera memcache om tillgängligt. Vidare information kan finnas i vår <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentation</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom är inte läsbar av PHP vilket definitivt inte är rekommenderat av säkerhetsskäl. Vidare information kan finnas i vår <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentation</a>.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Du kör för närvarande PHP {version}. Vi rekommenderar dig att uppgradera din PHP version så att ta fördel utav <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">prestanda och säkerhetsuppdateringar från PHP Group</a> så fort som din distribution stödjer det.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Konfiguration för \"reverse proxy headers\" är felaktig eller så försöker du nå Owncloud från en betrodd proxy. Om du inte försöker nå Owncloud från en betrodd proxy, detta är en säkerhetsrisk och kan möjliggöra att en hacker att förfalska sin IP adress som är synlig för Owncloud. Vidare information kan finnas i vår <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentation</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached är konfigurerad som distribuerad cache, men fel PHP modul \"memcache\" är installerad. \\OC\\Memcache\\Memcached stödjer bara \"memcached\" och inte \"memcache\". Se wiki för <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached för båda modulerna</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Några filer passerade inte integritetskontrollen. Vidare information om hur man löser dessa problem kan finnas i vår dokumentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lista över felaktiga filer…</a> / <a href=\"{rescanEndpoint}\">Sök igenom igen…</a>)",
    "Error occurred while checking server setup" : "Ett fel inträffade när en kontroll utav servens setup gjordes",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Din datakatalog och dina filer är sannolikt tillgängliga över internet. .htaccess filen fungerar ej korrekt. Vi uppmuntrar starkt att du konfigurerar din webbserver på ett sätt som inte gör din datakatalog tillgänglig på nätet eller att man flyttar hela datakatalogen ut ifrån webbserverns webbrot.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP headern är inte konfigurerad att evalueras till \"{expected}\". Detta är en potensiell säkerhetsrisk och vi rekommenderar dig åtgärda denna inställning.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "The \"Strict-Transport-Security\" HTTP headern är inte konfigurerad till minst \"{seconds}\" sekunder. För förbättrad säkerhet rekommenderas aktivering utav HSTS som beskrivs i våra <a href=\"{docUrl}\" rel=\"noreferrer\">säkerhetstips</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Du har begärt denna sidan över HTTP. Vi föreslår starkt att du konfigurerar din webbserver att kräva använding utav HTTPS istället, som beskrivs i våra <a href=\"{docUrl}\">säkerhetstips</a>.",
    "Shared" : "Delad",
    "Shared with {recipients}" : "Delad med {recipients}",
    "Error" : "Fel",
    "Error while sharing" : "Fel vid delning",
    "Error while unsharing" : "Fel när delning skulle avslutas",
    "The public link will expire no later than {days} days after it is created" : "Den publika länken kommer sluta gälla inte senare än {days} dagar efter att den skapades",
    "Set expiration date" : "Sätt utgångsdatum",
    "Expiration" : "Upphör",
    "Expiration date" : "Utgångsdatum",
    "Link" : "Länk",
    "Edit" : "Ändra",
    "Remove" : "Radera",
    "Copied!" : "Kopierad!",
    "Not supported!" : "Stöds inte!",
    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
    "Choose a password for the public link" : "Välj ett lösenord för den publika länken",
    "Filename" : "Filnamn",
    "Password" : "Lösenord",
    "Name" : "Namn",
    "Allow editing" : "Tillåt redigering",
    "Save" : "Spara",
    "Share to Twitter. Opens in a new window." : "Dela till Twitter. Öppnas i ett nytt fönster.",
    "Share to Facebook. Opens in a new window." : "Dela till Facebook. Öppnas i ett nytt fönster.",
    "Share to Diaspora. Opens in a new window." : "Dela till Diaspora. Öppnas i ett nytt fönster.",
    "Share to Google+. Opens in a new window." : "Dela till Google+. Öppnas i ett nytt fönster.",
    "Share via email. Opens your mail client." : "Dela via e-post. Öppnar din e-postklient.",
    "Error while sending notification" : "Fel när notifikation skulle skickas",
    "Sending ..." : "Skickar ...",
    "Email sent" : "E-post skickat",
    "Email link to person" : "E-posta länk till person",
    "Send link via email" : "Skicka länk via e-post",
    "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
    "Shared with you by {owner}" : "Delad med dig av {owner}",
    "group" : "Grupp",
    "remote" : "fjärr",
    "notify by email" : "informera via e-post",
    "Unshare" : "Sluta dela",
    "can share" : "får dela",
    "can edit" : "kan redigera",
    "create" : "skapa",
    "change" : "ändra",
    "delete" : "radera",
    "access control" : "åtkomstkontroll",
    "Could not unshare" : "Kunde inte odela",
    "Share details could not be loaded for this item." : "Delningsdetaljer kunde inte laddas för detta objekt.",
    "No users or groups found for {search}" : "Inga användare eller grupper funna för {search}",
    "No users found for {search}" : "Inga användare funna för {search}",
    "An error occurred. Please try again" : "Ett fel uppstod. Vänligen försök igen",
    "{sharee} (group)" : "{sharee} (group)",
    "{sharee} (at {server})" : "{sharee} (at {server})",
    "{sharee} (remote)" : "{sharee} (remote)",
    "Share" : "Dela",
    "Resharing is not allowed" : "Dela vidare är inte tillåtet",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Dela med folk på andra ownClouds med följande syntax username@example.com/owncloud",
    "Share with users…" : "Dela med användare...",
    "Share with users, groups or remote users…" : "Dela med användare, grupper och fjärranvändare...",
    "Share with users or groups…" : "Dela med användare eller grupper...",
    "Share with users or remote users…" : "Dela med användare eller fjärranvändare...",
    "Error removing share" : "Fel uppstod när delning försökte tas bort",
    "Warning" : "Varning",
    "Non-existing tag #{tag}" : "Icke-existerande tag #{tag}",
    "restricted" : "begränsad",
    "invisible" : "osynlig",
    "({scope})" : "({scope})",
    "Delete" : "Radera",
    "Rename" : "Byt namn",
    "Collaborative tags" : "Sammarbets taggar",
    "The object type is not specified." : "Objekttypen är inte specificerad.",
    "Enter new" : "Skriv nytt",
    "Add" : "Lägg till",
    "Edit tags" : "Redigera taggar",
    "Error loading dialog template: {error}" : "Fel vid inläsning av dialogmall: {fel}",
    "No tags selected for deletion." : "Inga taggar valda för borttagning.",
    "unknown text" : "okänd text",
    "Hello world!" : "Hej världen!",
    "sunny" : "soligt",
    "Hello {name}, the weather is {weather}" : "Hej {name}, vädret är {weather}",
    "Hello {name}" : "Hej {name}",
    "new" : "ny",
    "_download %n file_::_download %n files_" : ["Ladda ner %n fil","Ladda ner %n filer"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Uppgradering pågår, att lämna denna sidan kan störa processen i vissa miljöer",
    "Updating to {version}" : "Uppdaterar till {version}",
    "An error occurred." : "Ett fel inträffade.",
    "Please reload the page." : "Vänligen ladda om sidan.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppdateringen misslyckades. För mer information <a href=\"{url}\">kolla vår forum post</a> angående problemet.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Uppdateringen misslyckades. Rapportera detta problem till <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud Community</a>.",
    "The update was successful. There were warnings." : "Uppdateringen lyckades. Det finns varningar.",
    "The update was successful. Redirecting you to ownCloud now." : "Uppdateringen lyckades. Du omdirigeras nu till OwnCloud.",
    "Searching other places" : "Söker på andra platser",
    "No search results in other folders" : "Inga sökresultat i andra mappar",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} sökresultat i en annan mapp","{count} sökresultat i andra mappar"],
    "Personal" : "Personligt",
    "Users" : "Användare",
    "Apps" : "Program",
    "Admin" : "Admin",
    "Help" : "Hjälp",
    "Access forbidden" : "Åtkomst förbjuden",
    "File not found" : "Filen kunde inte hittas",
    "The specified document has not been found on the server." : "Det angivna dokumentet hittades inte på servern.",
    "You can click here to return to %s." : "Du kan klicka här för att återvända till %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hej där!,\n\nVi vill bara meddela att %s delade %s med dig.\nTitta på den här: %s\n\n",
    "The share will expire on %s." : "Utdelningen kommer att upphöra %s.",
    "Cheers!" : "Ha de fint!",
    "Internal Server Error" : "Internt serverfel",
    "The server encountered an internal error and was unable to complete your request." : "Servern påträffade ett internt fel och lmisslyckades att slutföra din begäran.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Vänligen kontakta serveradministratören om detta fel återkommer flera gånger, vänligen inkludera nedanstående tekniska detaljeri din felrapport.",
    "More details can be found in the server log." : "Mer detaljer återfinns i serverns logg.",
    "Technical details" : "Tekniska detaljer",
    "Remote Address: %s" : "Fjärradress: %s",
    "Request ID: %s" : "Begärd ID: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Meddelande: %s",
    "File: %s" : "Fil: %s",
    "Line: %s" : "Rad: %s",
    "Trace" : "Spåra",
    "Create an <strong>admin account</strong>" : "Skapa ett <strong>administratörskonto</strong>",
    "Username" : "Användarnamn",
    "Storage & database" : "Lagring & databas",
    "Data folder" : "Datamapp",
    "Configure the database" : "Konfigurera databasen",
    "Only %s is available." : "Endast %s är tillgänglig.",
    "Install and activate additional PHP modules to choose other database types." : "Installera och aktivera ytterligare moduler för att kunna välja andra databas-typer.",
    "For more details check out the documentation." : "För mer detaljer kolla dokumentationen",
    "Database user" : "Databasanvändare",
    "Database password" : "Lösenord till databasen",
    "Database name" : "Databasnamn",
    "Database tablespace" : "Databas tabellutrymme",
    "Database host" : "Databasserver",
    "Performance warning" : "Prestanda varning",
    "SQLite will be used as database." : "SQLite kommer att användas som databas",
    "For larger installations we recommend to choose a different database backend." : "För större installationer rekommenderar vi at man väljer en annan databasmotor.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Speciellt när desktop klienten för filsynkronisering används så avråds användande av SQLite.",
    "Finish setup" : "Avsluta installation",
    "Finishing …" : "Avslutar ...",
    "Need help?" : "Behöver du hjälp?",
    "See the documentation" : "Kolla dokumentationen",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hej där,<br><br>ville bara informera dig om att %s delade <strong>%s</strong> med dig.<br><a href=\"%s\">Visa den!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denna applikationen kräver JavaScript för att fungera korrekt. Var god {linkstart}aktivera JavaScript{linkend} och ladda om sidan.",
    "Log out" : "Logga ut",
    "Search" : "Sök",
    "Server side authentication failed!" : "Servern misslyckades med autentisering!",
    "Please contact your administrator." : "Kontakta din administratör.",
    "An internal error occurred." : "Ett internt fel uppstod.",
    "Please try again or contact your administrator." : "Vänligen försök igen eller kontakta din administratör.",
    "Username or email" : "Användarnamn eller e-post",
    "Log in" : "Logga in",
    "Wrong password. Reset it?" : "Fel lösenord. Vill du återställa?",
    "Wrong password." : "Fel lösenord.",
    "Stay logged in" : "Fortsätt vara inloggad.",
    "Alternative Logins" : "Alternativa inloggningar",
    "Use the following link to reset your password: {link}" : "Använd följande länk för att återställa lösenordet: {link}",
    "New password" : "Nytt lösenord",
    "New Password" : "Nytt lösenord",
    "Reset password" : "Återställ lösenordet",
    "This ownCloud instance is currently in single user mode." : "Denna ownCloud instans är för närvarande i enanvändarläge",
    "This means only administrators can use the instance." : "Detta betyder att endast administartörer kan använda instansen.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hör av dig till din systemadministratör ifall detta meddelande fortsätter eller visas oväntat.",
    "Thank you for your patience." : "Tack för ditt tålamod.",
    "Two-step verification" : "Tvåfaktorsautentisering",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Utökad säkerhet har aktiverats på ditt konto. Vänligen autentisera med en andra faktor.",
    "Cancel login" : "Avbryt inloggning",
    "Please authenticate using the selected factor." : "Vänligen autentisera med vald faktor.",
    "You are accessing the server from an untrusted domain." : "Du ansluter till servern från en osäker domän.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Var god kontakta din administratör. Om du är en administratör för denna installationen konfigurera \"trusted_domains\" i inställnings i config/config.php. En exempelkonfiguration återfinns i confg/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Beroende på din konfiguartion, så finns det möjlighet att du som administratör kan använda knappen nedan för att verifiera på denna domän.",
    "Add \"%s\" as trusted domain" : "Lägg till \"%s\" som en pålitlig domän",
    "App update required" : "Appen behöver uppdateras",
    "%s will be updated to version %s" : "%s kommer att uppdateras till version %s",
    "These apps will be updated:" : "Dessa appar kommer att uppdateras:",
    "The theme %s has been disabled." : "Temat  %s har blivit inaktiverat.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Vänligen säkerställ att en säkerhetskopia har gjorts av databasen, konfigurations- och datamappen innan du fortsätter.",
    "Start update" : "Starta uppdateringen",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "För att undvika timeout vid större installationer kan du istället köra följande kommando från din installationskatalog:",
    "Detailed logs" : "Detaljerade loggar",
    "Update needed" : "Uppdatering krävs",
    "Please use the command line updater because you have a big instance." : "Vänligen använd den kommandotolksbaserade uppdateringen eftersom du har en stor instans.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "För hjälp, se <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentationen</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Denna %s instans befinner sig för närvarande i underhållsläge, vilket kan ta ett tag.",
    "This page will refresh itself when the %s instance is available again." : "Denna sida uppdaterar sig själv när %s instansen är tillgänglig igen.",
    "Expiration date is required" : "Utgångsdatum krävs",
    "Remove link" : "Ta bort länk",
    "Create public link" : "Skapa publik länk",
    "Copy to clipboard" : "Kopiera till urklippshanteraren",
    "There are currently no link shares, you can create one" : "Det finns inga länkdelningar, men du kan skapa en",
    "Anyone with the link has access to the file/folder" : "Vem som helst med länken kan komma åt filen eller mappen",
    "Choose a password" : "Välj ett lösenord",
    "Password required" : "Lösenord krävs",
    "Upload only" : "Ladda bara upp",
    "Remove password" : "Ta bort lösenord",
    "Sending" : "Skickar",
    "User and Groups" : "Användare och grupper",
    "Public Links" : "Publika länkar",
    "Delete {link}" : "Ta bort {link}",
    "Menu" : "Meny",
    "Password changed successfully" : "Lösenordet ändrades",
    "Social share" : "Social delning",
    "An error occurred while verifying the token" : "Ett fel inträffade vid verifiering av nyckeln",
    "Link name" : "Länknamn",
    "%s password changed successfully" : "%s lösenord ändrades",
    "{fileName} link" : "{fileName} länk",
    "Edit link share: {name}" : "Ändra länkdelningen {name}",
    "Create link share: {name}" : "Skapa länkdelningen {name}",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Specifiera portnumret och värdnamnet (ex. localhost: 1337)",
    "Imprint" : "Imprint"
},
"nplurals=2; plural=(n != 1);");
